package com.tzld.piaoquan.risk.control.model.dto;

import lombok.Data;
import lombok.Setter;

import java.util.List;

@Data
public class Page<T> {

    private int currentPage = 1;
    private int totalSize;
    private int pageSize = 20;

    @Setter
    private List<T> objs;

    public Page() {
    }

    public Page(int currentPage) {
        this.currentPage = currentPage;
    }

    public Page(int currentPage, int pageSize) {
        setCurrentPage(currentPage);
        setPageSize(pageSize);
    }

    public int getNextPage() {
        return currentPage == getTotalPage() ? currentPage : currentPage + 1;
    }

    public int getPrePage() {
        return currentPage > 1 ? currentPage - 1 : 1;
    }

    public int getOffset() {
        return getCurPageFirstRecNum() - 1;
    }

    public int getCurPageFirstRecNum() {
        return (getCurrentPage() - 1) * pageSize + 1;
    }

    public int getCurPageLastRecNum() {
        return getCurrentPage() * pageSize;
    }

    public int getTotalPage() {
        int t = totalSize % pageSize > 0 ? totalSize / pageSize + 1 : totalSize / pageSize;
        if (t <= 0) {
            t = 1;
        }
        return t;
    }

    public void setPageSize(int pageSize) {
        if (pageSize > 0) {
            this.pageSize = pageSize;
        }
    }

    public boolean containData() {
        return getTotalSize() > 0;
    }

    @Override
    public String toString() {
        return "Page{" +
                "currentPage=" + currentPage +
                ", totalSize=" + totalSize +
                ", pageSize=" + pageSize +
                ", objs=" + objs +
                '}';
    }
}
