package com.tzld.piaoquan.risk.control.service.impl;

import com.alibaba.fastjson.JSON;
import com.tzld.piaoquan.risk.control.common.base.CommonResponse;
import com.tzld.piaoquan.risk.control.config.LoginUserContext;
import com.tzld.piaoquan.risk.control.config.QywxConfig;
import com.tzld.piaoquan.risk.control.dao.mapper.UserBaseMapper;
import com.tzld.piaoquan.risk.control.model.po.UserBase;
import com.tzld.piaoquan.risk.control.model.po.UserBaseExample;
import com.tzld.piaoquan.risk.control.model.qywx.QwCommonResModel;
import com.tzld.piaoquan.risk.control.model.qywx.QwInitResponseModel;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginCheckCode;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginQRCodeModel;
import com.tzld.piaoquan.risk.control.service.QwLoginService;
import com.tzld.piaoquan.risk.control.util.HttpClientUtil;
import com.tzld.piaoquan.risk.control.util.HttpPoolClient;
import org.apache.commons.collections4.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@Service
public class QwLoginServiceImpl implements QwLoginService {
    private static final HttpPoolClient httpPoolClientDefault = HttpClientUtil.create(10000, 10000, 2000, 5000, 5, 10000);
    @Autowired
    private QywxConfig qywxConfig; // 注入配置类
    @Autowired
    private QywxUserDataService qwUserService;
    @Value("${qwcallback.url}")
    private String qwCallbackUrl;
    private static final Logger LOGGER = LoggerFactory.getLogger(QwLoginServiceImpl.class);
    @Autowired
    private UserBaseMapper userBaseMapper;

    @Override
    public QwCommonResModel<QwLoginQRCodeModel> getLoginQRCode(String vid) {
        String uuid = "";
        uuid = initUUID(vid);
        // TODO 写入平台库表：platformPhone关联的uuid
        LOGGER.info("getLoginQRCode,uuid: {}", uuid);
        setCallback(uuid);
        if (uuid != null) {
            String url = qywxConfig.getDomain() + qywxConfig.getPath("login-qrcode");
            Map<String, Object> requestBody = new HashMap<>();
            requestBody.put("uuid", uuid);
            String params = JSON.toJSONString(requestBody);
            Optional<String> response = httpPoolClientDefault.postJson(url, params);
            if (response.isPresent()) {
                QwCommonResModel<QwLoginQRCodeModel> qrCodeModel = QwCommonResModel.parseResponse(response.get(), QwLoginQRCodeModel.class);
                qrCodeModel.getData().setUuid(uuid);
                return qrCodeModel;
            }
        }
        return null;
    }

    @Override
    public int checkQRCode(QwLoginCheckCode checkQrcode) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("login-checkcode");
        Optional<String> response = httpPoolClientDefault.postJson(url, JSON.toJSONString(checkQrcode));
        System.out.println("checkQRCode,response: " + response);
        LOGGER.info("checkQRCode,response: {}", response);
        if (response.isPresent()) {
            QwCommonResModel<Object> model = QwCommonResModel.parseResponse(response.get(), Object.class);
            return model.getErrcode();
        }
        return -1;
    }

    @Override
    public String getRunClients() {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("get-clients");
        Optional<String> response = httpPoolClientDefault.postJson(url, "");
        System.out.println("getRunClients,response: " + response);
        if (response.isPresent()) {
            return response.get();
        } else {
            System.out.println("Failed to get running clients: No response");
        }
        return "";
    }

    @Override
    public UserBase checkLogin(String uuid) {
        return qwUserService.getUserByUuid(uuid);
    }

    @Override
    public boolean quitLogin(String uuid) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("quit-login");
        Map<String, String> requestBody = new HashMap<>();
        requestBody.put("uuid", uuid);
        Optional<String> response =  httpPoolClientDefault.postJson(url, JSON.toJSONString(requestBody));

        boolean isSuccess = false;
        if (response.isPresent()) {
            QwCommonResModel<Object> model = QwCommonResModel.parseResponse(response.get(), Object.class);
            isSuccess =  model.getErrcode() == 0;
            //更改登录状态，根据uuid
            UserBaseExample example = new UserBaseExample();
            example.createCriteria().andUuidEqualTo(uuid);
            List<UserBase> userBases = userBaseMapper.selectByExample(example);
            if (CollectionUtils.isNotEmpty(userBases)) {
                UserBase update = userBases.get(0);
                update.setLoginStatus(0); // 设置登录状态为0
                userBaseMapper.updateByPrimaryKeySelective(update);
            }
        }
        return isSuccess;
    }

    @Override
    public QwCommonResModel<QwLoginQRCodeModel> secondaryValidation(String uuid) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("secondaryValidation");
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("uuid", uuid);
        String params = JSON.toJSONString(requestBody);
        Optional<String> response = httpPoolClientDefault.postJson(url, params);
        if (response.isPresent()) {
            QwCommonResModel<QwLoginQRCodeModel> qrCodeModel = QwCommonResModel.parseResponse(response.get(), QwLoginQRCodeModel.class);
            qrCodeModel.getData().setUuid(uuid);
            return qrCodeModel;
        }
        return null;
    }

    @Override
    public boolean automatedLogin(String uuid) {
        String url = qywxConfig.getDomain() + qywxConfig.getPath("auto-login");
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("uuid", uuid);
        Optional<String> response =  httpPoolClientDefault.postJson(url, JSON.toJSONString(requestBody));
        if (response.isPresent()) {
            QwCommonResModel<Object> model = QwCommonResModel.parseResponse(response.get(), Object.class);
            if (model.getErrcode() == 0) {
                return true;
            } else {
                return false;
            }
        }
        return false;
    }

    private String initUUID(String vid) {
        Long userId = LoginUserContext.getUserId();
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("vid", ""); // Add vid if available,二次登录使用上一次结果
        requestBody.put("ip", ""); // Add proxy IP if available
        requestBody.put("port", ""); // Add proxy port if available
        requestBody.put("proxyType", ""); // Add proxy type if available
        requestBody.put("userName", ""); // Add proxy username if available
        requestBody.put("passward", ""); // Add proxy password if available
        requestBody.put("proxySituation", 0); // Default value
        requestBody.put("deverType", "ipad"); // Default device type
        // Convert the request body to JSON string
        String params = JSON.toJSONString(requestBody);
        System.out.println("initUUID,params: " + params);

        String url = qywxConfig.getDomain() + qywxConfig.getPath("init-uuid");
        Optional<String> response = httpPoolClientDefault.postJson(url, params);
        // 直接解析 JSON
        if (response.isPresent()) {
            System.out.println("init,response: " + response);
            QwCommonResModel<QwInitResponseModel> initModel = QwCommonResModel.parseResponse(response.get(), QwInitResponseModel.class);
            String uuid = initModel.getData().getUuid();
            LOGGER.info("init success,uuid: {},platform user id:{}", uuid, userId);
            System.out.println("init success,uuid: " + uuid);
            this.saveUserBaseUUID(uuid, userId);
            return uuid;
        } else {
            return "";
        }
    }

    private void setCallback(String uuid) {
//        String callbackUrl = Constant.TEST_CALLBACK_URL; // Replace with your actual callback URL
        String url = qywxConfig.getDomain() + qywxConfig.getPath("add-qwcallback");
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("uuid", uuid);
        requestBody.put("url", qwCallbackUrl); // Add callback URL if available
        LOGGER.info("setCallback,uuid: {},url: {}", uuid, qwCallbackUrl);
        String params = JSON.toJSONString(requestBody);
        Optional<String> response = httpPoolClientDefault.postJson(url, params);
        if (response.isPresent()) {
            QwCommonResModel<Object> model = QwCommonResModel.parseResponse(response.get(), Object.class);
            System.out.println("setCallback success,response: " + response);
            LOGGER.info("setCallback success,response: {}", response);
            if (model.getErrcode() == 0) {
                System.out.println("Callback set successfully");
            } else {
                LOGGER.error("Failed to set callback: {}", model.getErrmsg());
                System.out.println("Failed to set callback: " + model.getErrmsg());
            }
        } else {
            System.out.println("Failed to set callback: No response");
        }
    }

    private void saveUserBaseUUID(String uuid, Long userId) {
        UserBaseExample example = new UserBaseExample();
        example.createCriteria().andUuidEqualTo(uuid);
        List<UserBase> userBases = userBaseMapper.selectByExample(example);
        if (CollectionUtils.isNotEmpty(userBases)) {
            UserBase update = userBases.get(0);
            update.setUpdateUser(userId);
            update.setUuid(uuid);
            update.setCreateUser(userId);
            userBaseMapper.updateByPrimaryKeySelective(update);
        } else {
            UserBase userBase = new UserBase();
            userBase.setUuid(uuid);
            userBase.setCreateUser(userId);
            userBase.setUpdateUser(userId);
            userBaseMapper.insertSelective(userBase);
        }
    }
}
